@@ -7,6 +7,7 @@
 import sys
 from distutils.dist import Distribution
 from extensions.command.install_egg_info import install_egg_info
+from extensions.command.egg_info import egg_info
 
 CMD_MODULE = 'extensions.command'
 
@@ -16,6 +17,7 @@ def get_command_class(self, command):
         CMD_MODULE not in self.command_packages):
         self.command_packages.append(CMD_MODULE)
     self.cmdclass['install_egg_info'] = install_egg_info
+    self.cmdclass['egg_info'] = egg_info
     return self._old_get_command_class(command)
 
 Distribution._old_get_command_class = Distribution.get_command_class
