@@ -1,10 +1,15 @@
 # -*- coding: utf8 -*-
 """ Plugin registry.
 """
+from ConfigParser import ConfigParser
 from collections import defaultdict
 
 _plugins = defaultdict(list)
 
+def reset():
+    global _plugins
+    _plugins = defaultdict(list)
+
 def register(group, name, value):
     """Registers a plugin, given a group, name and value."""
     if (name, value) not in _plugins[group]:
@@ -26,3 +31,12 @@ def stream_registered():
         return ''
     return '\n'.join(entries)
 
+def register_file(path):
+    """Registers a config-like file"""
+    parser = ConfigParser()
+    parser.read([path])
+    for group in parser.sections():
+        for name in parser.options(group):
+            value = parser.get(group, name)
+            register(group, name, value)
+
